---
id: behavioral-interview-rubrics
title: How candidates are evaluated in behavioral interviews at top tech companies
description: Detailed behavioral interview rubrics collated from big tech companies
keywords:
  [
    software engineer behavioral interview prep,
    software developer behavioral interview prep,
    behavioral interview software engineer,
    how to prepare for behavioral interview software engineer,
    google behavioral interview,
    facebook behavioral interview,
    amazon behavioral interview,
    microsoft behavioral interview,
  ]
sidebar_label: Behavioral interview rubrics
---

_The following page is contributed by [Lior Neu-ner](https://www.linkedin.com/in/liornn/) — former Meta engineering manager and founder of [Remote Rocketship](https://remoterocketship.com/), a job board for remote tech jobs._

## How behavioral interviews are evaluated

Unlike technical interviews, behavioral interviews have a lot more variance in terms of evaluation criteria. However, most top tech companies use their company values to evaluate candidates. Interviewers typically have to fill in a section evaluating how a candidate has displayed behaviors in line with company values. It is for this reason that you should search up a company's culture and values and ensure that you embody them within your answers. You'd also find it useful to speak with one of your connections currently working at the company you are applying for to find out more about which values are typically valued in the team.

Some examples of common values evaluated are:

- **Motivation** - What drives you? Ideal candidates are self-motivated, passionate about technologies and products that have a real impact.
- **Ability to be Proactive** - Are you able to take initiative? Given a difficult problem, are you able to figure out how to get it done and execute on it?
- **Ability to work in an unstructured environment** - How well are you able to take ownership in ambiguous situations? Or do you rely on others to be told what to do?
- **Perseverance** - Are you able to push through difficult problems or blockers?
- **Conflict Resolution** - How well are you able to handle and work through challenging relationships?
- **Empathy** - How well are you able to see things from the perspective of others and understand your motivations?
- **Growth** - How well do you understand your strengths, weaknesses and growth areas? Are you making a continued effort to grow?
- **Communication** - Are you able to clearly communicate your stories during the interview?

To assess these focus areas, interviewers ask questions on your work history and dig into the details of how you handled various situations. To assess your seniority, for each focus area they determine if the scope of the situation is something they would expect for a junior, senior, or staff engineer (more details on this below).

## Example questions and responses

Below are questions and answers illustrating how interviewers collect signals on the candidate for each focus area. In a typical interview, they'll ask you five or six questions and dive deep into the details of each situation. Each question may provide signals on more than one focus area.

### Motivation

Example Questions:

- What project are you most proud of and why?
- Tell me about a recent day working that was really great and/or fun.

Example Responses:

- Junior: A story about a project they are proud of that had an impact on their team.
- Senior: A story about a project they are proud of that had a large impact on their team.
- Staff: A story about a project they are proud of that had a large impact on their org.

### Ability to be proactive

Example Questions:

- Tell me about a time when you wanted to change something that was outside of your regular scope of work.
- Tell me about a time you had to make a fast decision and live with the results.

Example Responses:

- Junior: A story about a change they proactively suggested and drove that had an impact on their team’s focus area. Usually only requiring the candidate themselves to work on.
- Senior: A story about a change they proactively suggested and drove that had an impact on their entire team. Usually requiring three or more people to work on.
- Staff: A story about a change they proactively suggested and drove that had an impact on their entire org. Usually requiring two or more teams to work on.

### Ability to work in an unstructured environment

Example Questions:

- How do you decide what to work on next?
- Tell me about a project or task that was ambiguous or underspecified.

Example Responses:

- Junior: A story about an ambiguous task that the candidate took ownership of and was able to drive consensus from a few stakeholders in their team. Usually only requiring the candidate themselves to work on.
- Senior: A story about an ambiguous project that the candidate took ownership of and was able to drive consensus from stakeholders in their team or org. Usually requiring three or more people to work on.
- Staff: A story about an ambiguous project that the candidate took ownership of and was able to drive consensus from stakeholders in their org. Usually requiring two or more teams to work on.

### Perseverance

Example Questions:

- Tell me about a time when you needed to overcome external obstacles to complete a task or project.
- Tell me about a time a project took longer as expected

Example Responses:

- Junior: A story about a task with many technical difficulties and how they overcame each blocker.
- Senior: A story about a project with many technical difficulties that were blocking their team and how they overcame each blocker.
- Staff: A story about a project with many technical difficulties that were blocking many teams and how they overcame each blocker.

### Conflict resolution and empathy

Example Questions:

- Tell me about a person or team who you found the most challenging to work with.
- Tell me about a time you disagreed with a coworker.
- Tell me about a situation where two teams couldn’t agree on a path forward.

Example Responses:

- Junior: A story about how they were able to work through a disagreement with a coworker on an implementation detail of a larger project.
- Senior: A story about how they were able to work through a disagreement with a few coworkers or team leads on the direction of a larger project.
- Staff: A story about how they were able to work through a disagreement with two or more teams on the direction of a large project.

### Growth

Example Questions:

- Describe a situation when you made a mistake, and what you learned from it.
- Tell me about some constructive feedback you received from a manager or a peer.
- Tell me about a skill set that you observed in a peer or mentor that you want to develop in the next six months.

Example Responses:

- Junior: A story about a new technology they want to learn and the progress they have made to learn it.
- Senior: A story about a soft skill or technical skill they want to develop and the progress they have made to learn it. Usually a skill that will have the potential to affect the entire team.
- Staff: A story about a soft skill or technical skill they want to develop and the progress they have made to learn it. Usually a skill that will have the potential to affect two or more teams.

### Communication

- Generally covered during the interview as to how clearly they are explaining the stories. There is also some overlap with Empathy and how they communicate with others.

## After the interview

After the interview, the interviewer will compile their feedback and give a hire/no-hire recommendation as well as the candidate’s seniority. The hire/no-hire decision is given as a spectrum, ranging from low confidence to high confidence. This is illustrated below:

![The spectrum of the no-hire to hire interviewing decision overlayed on the interviewer's confidence](/img/interview-hire-spectrum.jpg)

The recommendation is compiled from the signals the interviewer collected on the eight focus areas. Typically, this looks like the following:

- For junior engineers, a hire recommendation is given if they showed positive signals on nearly all of the eight focus areas.
- For senior engineers, a hire recommendation is given if they showed positive signals on nearly all of the eight focus areas AND at the level we would expect for senior engineers. Otherwise, a no-hire recommendation is given.
- For staff engineers, a hire recommendation is given if they showed positive signals on nearly all of the eight focus areas AND at the level we would expect for staff engineers. Otherwise, a no-hire recommendation is given at a staff level, although they may give a hire recommendation at a senior level.

It’s worth mentioning that the interviewer’s decision is not final. Once all interview feedback has been collected from all interviews, the interviewers will discuss any concerns or strengths of the candidate with a "debrief committee".
