---
id: system-design
title: System design interview guide for Software Engineers
description: How to prepare for system design interviews for Software Engineers
keywords:
  [
    system design interview guide,
    how to prepare for system design interview,
    system design interview software engineer,
  ]
sidebar_label: System design preparation guide
---

<head>
  <meta property="og:image" content="https://www.techinterviewhandbook.org/social/system-design.png" />
</head>

The objective of system design interviews is to evaluate a candidate's skill at designing real-world software systems involving multiple components. System design questions are typically given to more senior candidates (with a few years of experience). Interns aren't typically given system design questions as it is hard to expect interns to have sufficient and relevant industry experience to answer this type of questions well.

## Types of system design interviews

System design questions can come in different formats:

- **Back end / distributed system design**: Candidates are asked to design systems that work across multiple servers or data centers. Topics include back end architecture, database schema design, data replication, fault tolerance, message queues, consistency models, and more.
- **API system design**: Design the APIs within a large system, possibly HTTP APIs (e.g. REST), or methods within a software component.
- **Object-oriented design**: Object-oriented design interviews focus on designing classes, objects, and their relationships. Candidates are often asked to create class diagrams, define interfaces, and discuss design patterns.
- **Front end system design**: Design the architecture of complex client applications or UI components. There's more emphasis on what goes on in the client and API design between the client and the server.

As software engineers, the most common type of system design you will encounter is the back end / distributed system design type. Some common back end system design interview questions include:

- Design a URL shortener (e.g. Bitly)
- Design a social media website (e.g. Twitter)
- Design a video watching website (e.g. YouTube)
- Design a chatting service (e.g. Telegram, Slack, Discord)
- Design a file sharing service (e.g. Google Drive, Dropbox)
- Design a ride sharing service (e.g. Uber, Lyft)
- Design a photo sharing service (e.g. Flickr, Pinterest)
- Design an e-commerce website (e.g. Amazon, eBay)
- Design a jobs portal (e.g. LinkedIn, Indeed)
- Design a web crawler (e.g. Google)

:::info

System design content is still work-in-progress, but the following are some resources to help you in the meanwhile.

:::

## Quality resources

- ["Front End System Design Guidebook" by GreatFrontEnd](https://www.greatfrontend.com/front-end-system-design-playbook?fpr=yangshun): A free system design guidebook by yours truly, focused on system design for the front end, e.g. how to design Facebook's News Feed, Autocomplete components, Image Carousels and more.
- [System Design in a Hurry](https://www.hellointerview.com/learn/system-design/in-a-hurry/introduction): Free course built by ex- Meta and Amazon engineers, covers the basics of delivery, high-level concepts, and core technologies. Worked "common problems" walk you through various design decisions in real problems and how to navigate them.
- [System Design Newsletter](https://newsletter.systemdesign.one/): Weekly newsletter on system design. Also get the powerful system design template for FREE.
- [ByteByteGo](https://bytebytego.com?fpr=techinterviewhandbook): This is a new System Design course by Alex Xu, author of the System Design Interview books, a bestseller on Amazon. The course covers system designs basics, then goes into deep dives of the design of over 10 famous common products (e.g. [Designing YouTube](https://bytebytego.com/courses/system-design-interview/design-youtube?fpr=techinterviewhandbook), Facebook Newsfeed, etc) and multiple big data and storage systems (e.g. [Designing a Chat System](https://bytebytego.com/courses/system-design-interview/design-a-chat-system?fpr=techinterviewhandbook)). For each deep dive, concepts are explained and comprehensive diagrams are used, making it very approachable regardless of seniority level.
- ["Grokking the System Design Interview" by Design Gurus](https://www.designgurus.io/course/grokking-the-system-design-interview?aff=kJSIoU): This is probably the most famous system design interview course on the internet and what makes it different from most other courses out there is that it is purely text-based, which is great for people who prefer reading over watching videos (such as myself!). It contains a repository of the popular system design problems along with a glossary of system design basics. I've personally completed this course and highly recommended many others to use this.
- ["Grokking the Advanced System Design Interview" by Design Gurus](https://www.designgurus.io/course/grokking-the-advanced-system-design-interview?aff=kJSIoU): I haven't tried this but it's by the same people who created "Grokking the System Design Interview", so it should be good! In my opinion you probably wouldn't need this unless you're very senior or going for a specialist position.
- ["Best of System Design" package by Design Gurus](https://www.designgurus.io/bundle/buy-both-system-design-courses?aff=kJSIoU): This bundle allows you to purchase both System Design interview courses by Design Gurus at a discount. Best of all, it's lifetime and not subscription-based.
- ["System Design Interview Course" by Exponent](https://www.tryexponent.com/courses/system-design-interviews?ref=techinterviewhandbook): This course covers system designs basics and has a huge database of popular system design questions with videos of mock interviews. Some of the questions have text answers and a database schema and APIs for reference (which I find helpful). While the subscription might be a little pricey for just the system design interviews content, they also offer quality technical content for [Data Structures](https://www.tryexponent.com/courses/swe-practice?ref=techinterviewhandbook), [Algorithms](https://www.tryexponent.com/courses/algorithms?ref=techinterviewhandbook) and [Behavioral Interviews](https://www.tryexponent.com/courses/behavioral?ref=techinterviewhandbook). The convenience of a one-stop platform which covers all aspects of technical interview preparation is very enticing.
- ["Gaurav Sen Youtube - System Design Playlist"](https://www.youtube.com/watch?v=xpDnVSmNFX0&feature=youtu.be): Gaurav Sen is a popular YouTuber who has gained a lot of recognition for his system design videos. His playlist on System Design provides a comprehensive guide for software engineers who are preparing for technical interviews or want to learn more about how to design scalable systems. The playlist consists of multiple videos, each video covering a different topic related to system design. The videos are designed in a way that simplifies complex topics and makes it easy to understand for beginners.

## Free resources

- [System Design Primer](https://github.com/donnemartin/system-design-primer): Most comprehensive resource on system design out there. Recommended only if you have a ton of time to spare.
- [System Design Interview](https://github.com/checkcheckzz/system-design-interview): Contains many links to tips about system design, system design-related topics and engineering blogs of famous companies.
- [System Design Cheatsheet](https://gist.github.com/vasanthk/485d1c25737e8e72759f): Brief and concise content. Serves as a good revision right before your system design interview.
- [System Design Roadmap](https://roadmap.sh/system-design): Step-by-step guide that includes links to articles and videos on learning essential topics.

## Books

- [System Design Interview – An insider's guide, Second Edition](https://www.amazon.com/System-Design-Interview-insiders-Second/dp/B08CMF2CQF): Beginner friendly resource to learn about system design, the content is easy to read and understand.
