---
id: understanding-compensation
title: Understanding compensation
---

import InDocAd from './\_components/InDocAd';

Compensation is one of the largest factors when it comes to deciding between job offers. This section gives you a breakdown of the common components of compensation in the tech industry.

In most companies, your compensation will consist of base salary, a performance bonus and equity/stocks. For compensation data, check out [Levels.fyi](https://www.levels.fyi?ref=TechInterviewHandbook&utm_source=techinterviewhandbook&utm_medium=referral&utm_content=website_negotiation).

## Base salary

Base salary is a fixed amount of salary you get for showing up at work and is unaffected by how well the company is performing or the industry is doing. It is the only non-variable component of your compensation.

Fresh graduates in the Bay Area can usually expect to get a base salary of above USD 100,000 (before taxes). The salary for fresh graduates at Facebook/Google is known to be in the USD 100,000 - 150,000 range.

Startups usually offer a bit higher for fresh graduate (USD 120,000 - 130,000) to make up for the lack of liquidity of the equity grant (not yet real cash).

Base salary doesn't increase linearly as you become more senior; it will taper off eventually. As employees become increasingly senior within the company, the higher the proportion of their compensation comes from company-dependent factors such as bonus and equity. This is because senior employees are expected to influence the people around them and drive the company forward. A senior employee's performance will be based on how well the company does as a whole; the individual factor will not be as much.

There are some exceptions to the system. Companies like Netflix pay top of the industry (sometimes even more than Facebook/Google) and give employees the option to receive their entire compensation as base salary, that is, to convert the equity component into their base. For the risk-adverse, this is a great choice.

## Bonus

Bonuses are usually paid on a semi-annual basis and are typically dependent on a few factors - level of seniority, individual performance in that time period, company performance in that time period.

- **Level of seniority** - This is usually a multiplier of the base salary and the multiplier increases as the employee moves up the ranks
- **Individual performance** - This is a multiplier of how well an employee performed in that time period. E.g. meeting expectations results in a 100% multiplier and exceeding expectations results in a >100% multiplier. Companies like Facebook and Apple reward their top performers handsomely, and the multiplier can go up to 300% for the extremely high-performing employees
- **Company performance** - How well the company is doing. This multiplier will be the same for all employees

### Examples

Bob is a Software Engineer fresh out of college. His base salary is $100,000, is a fresh grad (seniority multiplier: 10%), crushed expectations for the half (individual performance multiplier: 200%) and his company did pretty well (company performance multiplier: 120%). For that half, his bonus will be as follows:

**Bonus:** 100,000 x 50% (half a year) x 10% (seniority) x 200% (individual performance) x 120% (company performance) = 12000

Alice is an Engineering Manager with 10 years of professional experience. Her base salary is $220,000, is an experienced engineering manager (seniority multiplier: 20%), exceeded expectations for the half (individual performance multiplier: 150%) and her company did pretty awesome (company performance multiplier: 130%). For that half, her bonus will be as follows:

**Bonus:** 220,000 x 50% (half a year) x 20% (seniority) x 150% (individual performance) x 130% (company performance) = 42900

Hence the amount of bonus you receive can be highly variable and senior employees get a higher proportion of their total compensation from bonuses.

<InDocAd/>

## Equity/stocks

Equity is what differentiates a tech job from a non-tech one. Equity means a share of the company; this signifies ownership and motivates employees to work in the best interests of the company. They can be a significant portion of one's compensation, sometimes even more than the base salary, especially for senior employees.

Equity usually vests (becomes available to you) over a period of time (typically 4 years) and can vest equally every month/quarter/year. A vesting cliff means the minimum period of time before your vesting begins. For example, if you are granted 4,800 shares over a 4 year schedule with a 1 year cliff, and monthly vesting, you will get 1,200 shares at the end of your first year and 100 shares every month thereafter for the subsequent 3 years.

Until the company goes public (IPO) or gets acquired, the equity is usually not worth anything. However, there are instances where you can sell your stocks internally even though the company hasn't gone public. Be mindful of what you are getting yourself into!

Not all equity is treated equally. Depending on the company you join and which stage that company is at, you may receive one of the following types: stock options or stock grants.

### Stock options

Stock options are typically given by mid-stage companies. Stock options are different from stocks, which represents the immediate ownership of a company! Stock options are the **option/right** to purchase stocks at a given strike price, hence it's not free. However, the cost of each stock is usually quite low and fixed at a strike price, which is equal to the fair market value of the stock when it was granted to you. You are guaranteed to be able to purchase the stock at that price regardless of future increases.

When you leave a company, there is an exercise window (deadline given for you to exercise your options before they are gone), so it is important to have enough liquid cash to purchase them when planning a departure.

### Stock grants

A stock grant is commonly referred to as a Restricted Stock Unit (RSU) and it means you possess the stock immediately. If the company is public, you can sell them during defined trading windows.

More reading on the topic can be done on the [equity compensation guide](https://github.com/jlevy/og-equity-compensation) and the article ["What I Wish I'd Known About Equity Before Joining A Unicorn"](https://gist.github.com/yossorion/4965df74fd6da6cdc280ec57e83a202d).

## Signing bonus

This is a one-time lump sum that is paid to you when you join a company. This amount is typically in the range of USD 10,000 to USD 20,000 but can even go up to USD 50,000 (Google) and USD 100,000 (Facebook).

There can be conditions attached to signing bonuses, such as having to return a pro-rated amount if an employee leaves before the one-year mark. Make sure you are aware of them before you sign the offer.

<InDocAd/>

## Misc bonuses/perks

While these perks are not exactly cash, they can help you save money which is almost equivalent to getting compensated more. Do find out more about these from your recruiters if you get the chance.

- **Free meals** - Food is not exactly cheap in the Bay Area and having some meals provided on weekdays can result in saving few thousand dollars a year and hours spent on travelling out to get food
- **Relocation bonus** - Helpful if you are moving from abroad. This can partially offset costs incurred during relocation
- **Health and dental insurance/plans** - Companies often partner with insurance companies to provide employees with health and dental plans. These can amount to a few thousand dollars worth annually and is especially useful in locations where healthcare is expensive
- **Shuttle service** - Public transportation in the Bay Area is not that great and the most common form of commute is driving. Being able to take a shuttle service helps in saving money on gas, transport, and freeing up your mind to do other things during the commute

## Examples

Here's crowdsourced data from Google and Facebook regarding the salaries for the various levels:

### Google

| Level                   | Total (USD) | Base     | Bonus    | Stock (/yr) |
| ----------------------- | ----------- | -------- | -------- | ----------- |
| L3 (Entry Level)        | $191,000    | $131,000 | $21,000  | $39,000     |
| L4 (SWE)                | $267,000    | $158,000 | $28,000  | $81,000     |
| L5 (Senior SWE)         | $355,000    | $188,000 | $37,000  | $130,000    |
| L6 (Staff SWE)          | $489,000    | $223,000 | $50,000  | $214,000    |
| L7 (Senior Staff SWE)   | $672,000    | $263,000 | $79,000  | $330,000    |
| L8 (Principal Engineer) | $1,020,000  | $331,000 | $119,000 | $572,000    |

_Data as of Aug 2021. Source: [Levels.fyi](https://www.levels.fyi/company/Google/salaries/Software-Engineer/?ref=TechInterviewHandbook&utm_source=techinterviewhandbook&utm_medium=referral&utm_content=website_negotiation)_

### Facebook

| Level                 | Total (USD) | Base     | Bonus   | Stock (/yr) |
| --------------------- | ----------- | -------- | ------- | ----------- |
| E3 (Entry Level)      | $180,000    | $122,000 | $14,000 | $43,000     |
| E4 (SWE)              | $267,000    | $162,000 | $18,000 | $85,000     |
| E5 (Senior SWE)       | $390,000    | $197,000 | $35,000 | $157,000    |
| E6 (Staff SWE)        | $598,000    | $234,000 | $54,000 | $309,000    |
| E7 (Senior Staff SWE) | $921,000    | $272,000 | $81,000 | $567,000    |

_Data as of Aug 2021. Source: [Levels.fyi](https://www.levels.fyi/company/Facebook/salaries/Software-Engineer/?ref=TechInterviewHandbook&utm_source=techinterviewhandbook&utm_medium=referral&utm_content=website_negotiation)_
